@@ -84,8 +84,8 @@ class Mergable(metaclass=abc.ABCMeta):
     def merge(self, *args):
         """Merge this instance with new instances, in-place.
 
-        :param *args: Configuration values to merge with current instance.
-        :type *args: iterable
+        :param args: Configuration values to merge with current instance.
+        :type args: iterable
 
         """
         for data in args:
